@@ -133,7 +133,7 @@ class powerswitch:
         if self.off(outlet):
           return True
         time.sleep(self.cycletime)
-        self.on(outlet):
+        self.on(outlet)
         return False
     def statuslist(self):
         """ Return the status of all outlets in a list, 
